@@ -10,6 +10,9 @@ pub enum Error {
     #[error("IO error: {0}")]
     Io(#[from] std::io::Error),
 
+    #[error("Could not open file {0:?}: {1}")]
+    OpenFile(PathBuf, std::io::Error),
+
     #[error("Walkdir error: {0}")]
     WalkDir(#[from] walkdir::Error),
 
